==> jc-1.4.0.tar.gz: javax/net/ssl/KeyManagerFactorySpi.h <==
// public abstract class javax.net.ssl.KeyManagerFactorySpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6b3456faafb71978 javax_net_ssl_KeyManagerFactorySpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_net_ssl_KeyManagerFactorySpi_H_
#define _JC_javax_net_ssl_KeyManagerFactorySpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_KeyStore$object;
struct _jc_javax_net_ssl_ManagerFactoryParameters$object;

// Typedefs
typedef struct _jc_javax_net_ssl_KeyManagerFactorySpi$sub_refs	_jc_javax_net_ssl_KeyManagerFactorySpi$sub_refs;
typedef struct _jc_javax_net_ssl_KeyManagerFactorySpi$sub_nonrefs	_jc_javax_net_ssl_KeyManagerFactorySpi$sub_nonrefs;
typedef struct _jc_javax_net_ssl_KeyManagerFactorySpi$refs	_jc_javax_net_ssl_KeyManagerFactorySpi$refs;
typedef struct _jc_javax_net_ssl_KeyManagerFactorySpi$nonrefs	_jc_javax_net_ssl_KeyManagerFactorySpi$nonrefs;
typedef struct _jc_javax_net_ssl_KeyManagerFactorySpi$object	_jc_javax_net_ssl_KeyManagerFactorySpi$object;

typedef const struct _jc_javax_net_ssl_KeyManagerFactorySpi$vmethods	_jc_javax_net_ssl_KeyManagerFactorySpi$vmethods;
typedef const struct _jc_javax_net_ssl_KeyManagerFactorySpi$vtable	_jc_javax_net_ssl_KeyManagerFactorySpi$vtable;
typedef const struct _jc_javax_net_ssl_KeyManagerFactorySpi$vtype	_jc_javax_net_ssl_KeyManagerFactorySpi$vtype;

// Constructors
extern void _jc_javax_net_ssl_KeyManagerFactorySpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *);

// Virtual methods
extern _jc_object_array *_jc_javax_net_ssl_KeyManagerFactorySpi$method$engineGetKeyManagers$645758138549fcb4(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *);
extern void _jc_javax_net_ssl_KeyManagerFactorySpi$method$engineInit$c2175b213ac485fe(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *, struct _jc_java_security_KeyStore$object *, struct _jc_char_array *);
extern void _jc_javax_net_ssl_KeyManagerFactorySpi$method$engineInit$7d0f73d1c75dca0e(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_KeyManagerFactorySpi$method_info$engineGetKeyManagers$645758138549fcb4;
extern _jc_method _jc_javax_net_ssl_KeyManagerFactorySpi$method_info$engineInit$c2175b213ac485fe;
extern _jc_method _jc_javax_net_ssl_KeyManagerFactorySpi$method_info$engineInit$7d0f73d1c75dca0e;

// Virtual methods structure
struct _jc_javax_net_ssl_KeyManagerFactorySpi$vmethods {
	_jc_object_array	*(*engineGetKeyManagers$645758138549fcb4)(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *);
	void	(*engineInit$c2175b213ac485fe)(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *, struct _jc_java_security_KeyStore$object *, struct _jc_char_array *);
	void	(*engineInit$7d0f73d1c75dca0e)(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_net_ssl_KeyManagerFactorySpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ssl_KeyManagerFactorySpi$vmethods	javax_net_ssl_KeyManagerFactorySpi;
};

// Vtype
struct _jc_javax_net_ssl_KeyManagerFactorySpi$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_KeyManagerFactorySpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_KeyManagerFactorySpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_KeyManagerFactorySpi$refs {
    _jc_javax_net_ssl_KeyManagerFactorySpi$sub_refs	javax_net_ssl_KeyManagerFactorySpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_KeyManagerFactorySpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_KeyManagerFactorySpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ssl_KeyManagerFactorySpi$sub_nonrefs	javax_net_ssl_KeyManagerFactorySpi;
};

// Object instance structure
struct _jc_javax_net_ssl_KeyManagerFactorySpi$object {
	_jc_javax_net_ssl_KeyManagerFactorySpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_KeyManagerFactorySpi$vtype	*vtype;
	_jc_javax_net_ssl_KeyManagerFactorySpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_KeyManagerFactorySpi$vtype _jc_javax_net_ssl_KeyManagerFactorySpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_KeyManagerFactorySpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_KeyManagerFactorySpi$class_object;

#endif	/* _JC_javax_net_ssl_KeyManagerFactorySpi_H_ */

==> jc-1.4.6.tar.gz: javax/net/ssl/KeyManagerFactorySpi.h <==
// public abstract class javax.net.ssl.KeyManagerFactorySpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6b3456faafb71978 javax_net_ssl_KeyManagerFactorySpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_net_ssl_KeyManagerFactorySpi_H_
#define _JC_javax_net_ssl_KeyManagerFactorySpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_KeyStore$object;
struct _jc_javax_net_ssl_ManagerFactoryParameters$object;

// Typedefs
typedef struct _jc_javax_net_ssl_KeyManagerFactorySpi$sub_refs	_jc_javax_net_ssl_KeyManagerFactorySpi$sub_refs;
typedef struct _jc_javax_net_ssl_KeyManagerFactorySpi$sub_nonrefs	_jc_javax_net_ssl_KeyManagerFactorySpi$sub_nonrefs;
typedef struct _jc_javax_net_ssl_KeyManagerFactorySpi$refs	_jc_javax_net_ssl_KeyManagerFactorySpi$refs;
typedef struct _jc_javax_net_ssl_KeyManagerFactorySpi$nonrefs	_jc_javax_net_ssl_KeyManagerFactorySpi$nonrefs;
typedef struct _jc_javax_net_ssl_KeyManagerFactorySpi$object	_jc_javax_net_ssl_KeyManagerFactorySpi$object;

typedef const struct _jc_javax_net_ssl_KeyManagerFactorySpi$vmethods	_jc_javax_net_ssl_KeyManagerFactorySpi$vmethods;
typedef const struct _jc_javax_net_ssl_KeyManagerFactorySpi$vtable	_jc_javax_net_ssl_KeyManagerFactorySpi$vtable;
typedef const struct _jc_javax_net_ssl_KeyManagerFactorySpi$vtype	_jc_javax_net_ssl_KeyManagerFactorySpi$vtype;

// Constructors
extern void _jc_javax_net_ssl_KeyManagerFactorySpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_javax_net_ssl_KeyManagerFactorySpi$method$engineGetKeyManagers$645758138549fcb4(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *) _JC_JCNI_ATTR;
extern void _jc_javax_net_ssl_KeyManagerFactorySpi$method$engineInit$c2175b213ac485fe(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *, struct _jc_java_security_KeyStore$object *, struct _jc_char_array *) _JC_JCNI_ATTR;
extern void _jc_javax_net_ssl_KeyManagerFactorySpi$method$engineInit$7d0f73d1c75dca0e(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_KeyManagerFactorySpi$method_info$engineGetKeyManagers$645758138549fcb4;
extern _jc_method _jc_javax_net_ssl_KeyManagerFactorySpi$method_info$engineInit$c2175b213ac485fe;
extern _jc_method _jc_javax_net_ssl_KeyManagerFactorySpi$method_info$engineInit$7d0f73d1c75dca0e;

// Virtual methods structure
struct _jc_javax_net_ssl_KeyManagerFactorySpi$vmethods {
	_jc_object_array	*(*engineGetKeyManagers$645758138549fcb4)(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *) _JC_JCNI_ATTR;
	void	(*engineInit$c2175b213ac485fe)(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *, struct _jc_java_security_KeyStore$object *, struct _jc_char_array *) _JC_JCNI_ATTR;
	void	(*engineInit$7d0f73d1c75dca0e)(_jc_env *, struct _jc_javax_net_ssl_KeyManagerFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_net_ssl_KeyManagerFactorySpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ssl_KeyManagerFactorySpi$vmethods	javax_net_ssl_KeyManagerFactorySpi;
};

// Vtype
struct _jc_javax_net_ssl_KeyManagerFactorySpi$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_KeyManagerFactorySpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_KeyManagerFactorySpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_KeyManagerFactorySpi$refs {
    _jc_javax_net_ssl_KeyManagerFactorySpi$sub_refs	javax_net_ssl_KeyManagerFactorySpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_KeyManagerFactorySpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_KeyManagerFactorySpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ssl_KeyManagerFactorySpi$sub_nonrefs	javax_net_ssl_KeyManagerFactorySpi;
};

// Object instance structure
struct _jc_javax_net_ssl_KeyManagerFactorySpi$object {
	_jc_javax_net_ssl_KeyManagerFactorySpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_KeyManagerFactorySpi$vtype	*vtype;
	_jc_javax_net_ssl_KeyManagerFactorySpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_KeyManagerFactorySpi$vtype _jc_javax_net_ssl_KeyManagerFactorySpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_KeyManagerFactorySpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_KeyManagerFactorySpi$class_object;

#endif	/* _JC_javax_net_ssl_KeyManagerFactorySpi_H_ */
